@@ -299,24 +299,24 @@ static vector<uint8_t> makeBigReferral()
   for(char c='a'; c<= 'm';++c) {
     pw.startRecord(DNSName("com"), QType::NS, 3600, 1, DNSResourceRecord::AUTHORITY);
     gtld[0]=c;
-    auto drc = DNSRecordContent::mastermake(QType::NS, 1, gtld);
+    auto drc = DNSRecordContent::make(QType::NS, 1, gtld);
     drc->toPacket(pw);
   }
 
   for(char c='a'; c<= 'k';++c) {
     gtld[0]=c;
     pw.startRecord(DNSName(gtld), QType::A, 3600, 1, DNSResourceRecord::ADDITIONAL);
-    auto drc = DNSRecordContent::mastermake(QType::A, 1, "1.2.3.4");
+    auto drc = DNSRecordContent::make(QType::A, 1, "1.2.3.4");
     drc->toPacket(pw);
   }
 
 
   pw.startRecord(DNSName("a.gtld-servers.net"), QType::AAAA, 3600, 1, DNSResourceRecord::ADDITIONAL);
-  auto aaaarc = DNSRecordContent::mastermake(QType::AAAA, 1, "2001:503:a83e::2:30");
+  auto aaaarc = DNSRecordContent::make(QType::AAAA, 1, "2001:503:a83e::2:30");
   aaaarc->toPacket(pw);
 
   pw.startRecord(DNSName("b.gtld-servers.net"), QType::AAAA, 3600, 1, DNSResourceRecord::ADDITIONAL);
-  aaaarc = DNSRecordContent::mastermake(QType::AAAA, 1, "2001:503:231d::2:30");
+  aaaarc = DNSRecordContent::make(QType::AAAA, 1, "2001:503:231d::2:30");
   aaaarc->toPacket(pw);
 
 
@@ -363,7 +363,7 @@ static vector<uint8_t> makeBigDNSPacketReferral()
   //  shuffle(records);
   for(const auto& rec : records) {
     pw.startRecord(rec.qname, rec.qtype.getCode(), rec.ttl, 1, DNSResourceRecord::ADDITIONAL);
-    auto drc = DNSRecordContent::mastermake(rec.qtype.getCode(), 1, rec.content);
+    auto drc = DNSRecordContent::make(rec.qtype.getCode(), 1, rec.content);
     drc->toPacket(pw);
   }
 
@@ -382,8 +382,8 @@ struct MakeARecordTestMM
 
   void operator()() const
   {
-      auto drc = DNSRecordContent::mastermake(QType::A, 1,
-                                              "1.2.3.4");
+    auto drc = DNSRecordContent::make(QType::A, 1,
+                                      "1.2.3.4");
   }
 };
 
@@ -455,8 +455,8 @@ struct GenericRecordTest
     DNSPacketWriter pw(packet, DNSName("outpost.ds9a.nl"), d_type);
     for(int records = 0; records < d_records; records++) {
       pw.startRecord(DNSName("outpost.ds9a.nl"), d_type);
-      auto drc = DNSRecordContent::mastermake(d_type, 1,
-                                              d_content);
+      auto drc = DNSRecordContent::make(d_type, 1,
+                                        d_content);
       drc->toPacket(pw);
     }
     pw.commit();
@@ -482,7 +482,7 @@ struct AAAARecordTest
     DNSPacketWriter pw(packet, DNSName("outpost.ds9a.nl"), QType::AAAA);
     for(int records = 0; records < d_records; records++) {
       pw.startRecord(DNSName("outpost.ds9a.nl"), QType::AAAA);
-      auto drc = DNSRecordContent::mastermake(QType::AAAA, 1, "fe80::21d:92ff:fe6d:8441");
+      auto drc = DNSRecordContent::make(QType::AAAA, 1, "fe80::21d:92ff:fe6d:8441");
       drc->toPacket(pw);
     }
     pw.commit();
@@ -506,7 +506,7 @@ struct SOARecordTest
 
     for(int records = 0; records < d_records; records++) {
       pw.startRecord(DNSName("outpost.ds9a.nl"), QType::SOA);
-      auto drc = DNSRecordContent::mastermake(QType::SOA, 1, "a0.org.afilias-nst.info. noc.afilias-nst.info. 2008758137 1800 900 604800 86400");
+      auto drc = DNSRecordContent::make(QType::SOA, 1, "a0.org.afilias-nst.info. noc.afilias-nst.info. 2008758137 1800 900 604800 86400");
       drc->toPacket(pw);
     }
     pw.commit();
@@ -527,20 +527,20 @@ static vector<uint8_t> makeTypicalReferral()
   DNSPacketWriter pw(packet, DNSName("outpost.ds9a.nl"), QType::A);
 
   pw.startRecord(DNSName("ds9a.nl"), QType::NS, 3600, 1, DNSResourceRecord::AUTHORITY);
-  auto drc = DNSRecordContent::mastermake(QType::NS, 1, "ns1.ds9a.nl");
+  auto drc = DNSRecordContent::make(QType::NS, 1, "ns1.ds9a.nl");
   drc->toPacket(pw);
 
   pw.startRecord(DNSName("ds9a.nl"), QType::NS, 3600, 1, DNSResourceRecord::AUTHORITY);
-  drc = DNSRecordContent::mastermake(QType::NS, 1, "ns2.ds9a.nl");
+  drc = DNSRecordContent::make(QType::NS, 1, "ns2.ds9a.nl");
   drc->toPacket(pw);
 
 
   pw.startRecord(DNSName("ns1.ds9a.nl"), QType::A, 3600, 1, DNSResourceRecord::ADDITIONAL);
-  drc = DNSRecordContent::mastermake(QType::A, 1, "1.2.3.4");
+  drc = DNSRecordContent::make(QType::A, 1, "1.2.3.4");
   drc->toPacket(pw);
 
   pw.startRecord(DNSName("ns2.ds9a.nl"), QType::A, 3600, 1, DNSResourceRecord::ADDITIONAL);
-  drc = DNSRecordContent::mastermake(QType::A, 1, "4.3.2.1");
+  drc = DNSRecordContent::make(QType::A, 1, "4.3.2.1");
   drc->toPacket(pw);
 
   pw.commit();
@@ -673,7 +673,7 @@ struct ParsePacketTest
       rr.qname=i->first.d_name;
 
       rr.ttl=i->first.d_ttl;
-      rr.content=i->first.d_content->getZoneRepresentation();  // this should be the serialised form
+      rr.content=i->first.getContent()->getZoneRepresentation();  // this should be the serialised form
       lwr.d_result.push_back(rr);
     }
 
@@ -939,7 +939,7 @@ struct UUIDGenTest
 
 struct NSEC3HashTest
 {
-  explicit NSEC3HashTest(int iterations, string salt) : d_iterations(iterations), d_salt(salt) {}
+  explicit NSEC3HashTest(int iterations, string salt) : d_iterations(iterations), d_salt(std::move(salt)) {}
 
   string getName() const
   {
@@ -1084,7 +1084,6 @@ struct RndSpeedTest
   explicit RndSpeedTest(std::string which) : name(which){
     ::arg().set("entropy-source", "If set, read entropy from this file")="/dev/urandom";
     ::arg().set("rng", "") = which;
-    dns_random_init("", true);
   }
   string getName() const
   {
@@ -1182,166 +1181,169 @@ private:
 };
 #endif
 
-int main(int argc, char** argv)
-try
+int main()
 {
-  reportAllTypes();
+  try {
+    reportAllTypes();
 
-  doRun(NOPTest());
+    doRun(NOPTest());
 
-  doRun(IEqualsTest());
-  doRun(MyIEqualsTest());
-  doRun(StrcasecmpTest());
-  doRun(Base64EncodeTest());
-  doRun(B64DecodeTest());
+    doRun(IEqualsTest());
+    doRun(MyIEqualsTest());
+    doRun(StrcasecmpTest());
+    doRun(Base64EncodeTest());
+    doRun(B64DecodeTest());
 
-  doRun(StackMallocTest());
+    doRun(StackMallocTest());
 
-  doRun(EmptyQueryTest());
-  doRun(TypicalRefTest());
-  doRun(BigRefTest());
-  doRun(BigDNSPacketRefTest());
+    doRun(EmptyQueryTest());
+    doRun(TypicalRefTest());
+    doRun(BigRefTest());
+    doRun(BigDNSPacketRefTest());
 
-  auto packet = makeEmptyQuery();
-  doRun(ParsePacketTest(packet, "empty-query"));
+    auto packet = makeEmptyQuery();
+    doRun(ParsePacketTest(packet, "empty-query"));
 
-  packet = makeTypicalReferral();
-  cerr<<"typical referral size: "<<packet.size()<<endl;
-  doRun(ParsePacketBareTest(packet, "typical-referral"));
+    packet = makeTypicalReferral();
+    cerr<<"typical referral size: "<<packet.size()<<endl;
+    doRun(ParsePacketBareTest(packet, "typical-referral"));
 
-  doRun(ParsePacketTest(packet, "typical-referral"));
+    doRun(ParsePacketTest(packet, "typical-referral"));
 
-  doRun(SimpleCompressTest("www.france.ds9a.nl"));
+    doRun(SimpleCompressTest("www.france.ds9a.nl"));
 
 
-  doRun(VectorExpandTest());
+    doRun(VectorExpandTest());
 
-  doRun(GetTimeTest());
+    doRun(GetTimeTest());
 
-  doRun(GetLockUncontendedTest());
-  doRun(GetUniqueLockUncontendedTest());
-  doRun(GetLockGuardUncontendedTest());
-  doRun(GetLockGuardedUncontendedTest());
-  doRun(SharedLockTest());
+    doRun(GetLockUncontendedTest());
+    doRun(GetUniqueLockUncontendedTest());
+    doRun(GetLockGuardUncontendedTest());
+    doRun(GetLockGuardedUncontendedTest());
+    doRun(SharedLockTest());
 
-  {
-    ReadWriteLock rwlock;
-    doRun(ReadWriteLockSharedTest(rwlock));
-    doRun(ReadWriteLockExclusiveTest(rwlock));
-    doRun(ReadWriteLockExclusiveTryTest(rwlock, false));
     {
-      ReadLock rl(rwlock);
-      doRun(ReadWriteLockExclusiveTryTest(rwlock, true));
-      doRun(ReadWriteLockSharedTryTest(rwlock, false));
+      ReadWriteLock rwlock;
+      doRun(ReadWriteLockSharedTest(rwlock));
+      doRun(ReadWriteLockExclusiveTest(rwlock));
+      doRun(ReadWriteLockExclusiveTryTest(rwlock, false));
+      {
+        ReadLock rl(rwlock);
+        doRun(ReadWriteLockExclusiveTryTest(rwlock, true));
+        doRun(ReadWriteLockSharedTryTest(rwlock, false));
+      }
+      {
+        WriteLock wl(rwlock);
+        doRun(ReadWriteLockSharedTryTest(rwlock, true));
+      }
     }
-    {
-      WriteLock wl(rwlock);
-      doRun(ReadWriteLockSharedTryTest(rwlock, true));
-    }
-  }
 
-  doRun(StaticMemberTest());
+    doRun(StaticMemberTest());
 
-  doRun(ARecordTest(1));
-  doRun(ARecordTest(2));
-  doRun(ARecordTest(4));
-  doRun(ARecordTest(64));
+    doRun(ARecordTest(1));
+    doRun(ARecordTest(2));
+    doRun(ARecordTest(4));
+    doRun(ARecordTest(64));
 
-  doRun(A2RecordTest(1));
-  doRun(A2RecordTest(2));
-  doRun(A2RecordTest(4));
-  doRun(A2RecordTest(64));
+    doRun(A2RecordTest(1));
+    doRun(A2RecordTest(2));
+    doRun(A2RecordTest(4));
+    doRun(A2RecordTest(64));
 
-  doRun(MakeStringFromCharStarTest());
-  doRun(MakeARecordTest());
-  doRun(MakeARecordTestMM());
+    doRun(MakeStringFromCharStarTest());
+    doRun(MakeARecordTest());
+    doRun(MakeARecordTestMM());
 
-  doRun(AAAARecordTest(1));
-  doRun(AAAARecordTest(2));
-  doRun(AAAARecordTest(4));
-  doRun(AAAARecordTest(64));
+    doRun(AAAARecordTest(1));
+    doRun(AAAARecordTest(2));
+    doRun(AAAARecordTest(4));
+    doRun(AAAARecordTest(64));
 
-  doRun(TXTRecordTest(1));
-  doRun(TXTRecordTest(2));
-  doRun(TXTRecordTest(4));
-  doRun(TXTRecordTest(64));
+    doRun(TXTRecordTest(1));
+    doRun(TXTRecordTest(2));
+    doRun(TXTRecordTest(4));
+    doRun(TXTRecordTest(64));
 
-  doRun(GenericRecordTest(1, QType::NS, "powerdnssec1.ds9a.nl"));
-  doRun(GenericRecordTest(2, QType::NS, "powerdnssec1.ds9a.nl"));
-  doRun(GenericRecordTest(4, QType::NS, "powerdnssec1.ds9a.nl"));
-  doRun(GenericRecordTest(64, QType::NS, "powerdnssec1.ds9a.nl"));
+    doRun(GenericRecordTest(1, QType::NS, "powerdnssec1.ds9a.nl"));
+    doRun(GenericRecordTest(2, QType::NS, "powerdnssec1.ds9a.nl"));
+    doRun(GenericRecordTest(4, QType::NS, "powerdnssec1.ds9a.nl"));
+    doRun(GenericRecordTest(64, QType::NS, "powerdnssec1.ds9a.nl"));
 
-  doRun(SOARecordTest(1));
-  doRun(SOARecordTest(2));
-  doRun(SOARecordTest(4));
-  doRun(SOARecordTest(64));
+    doRun(SOARecordTest(1));
+    doRun(SOARecordTest(2));
+    doRun(SOARecordTest(4));
+    doRun(SOARecordTest(64));
 
-  doRun(StringtokTest());
-  doRun(VStringtokTest());
-  doRun(StringAppendTest());
-  doRun(BoostStringAppendTest());
+    doRun(StringtokTest());
+    doRun(VStringtokTest());
+    doRun(StringAppendTest());
+    doRun(BoostStringAppendTest());
 
-  doRun(DNSNameParseTest());
-  doRun(DNSNameRootTest());
+    doRun(DNSNameParseTest());
+    doRun(DNSNameRootTest());
 
-  doRun(SuffixMatchNodeTest());
+    doRun(SuffixMatchNodeTest());
 
-  doRun(NetmaskTreeTest());
+    doRun(NetmaskTreeTest());
 
-  doRun(UUIDGenTest());
+    doRun(UUIDGenTest());
 
 #if defined(HAVE_GETRANDOM)
-  doRun(RndSpeedTest("getrandom"));
+    doRun(RndSpeedTest("getrandom"));
 #endif
 #if defined(HAVE_ARC4RANDOM)
-  doRun(RndSpeedTest("arc4random"));
+    doRun(RndSpeedTest("arc4random"));
 #endif
 #if defined(HAVE_RANDOMBYTES_STIR)
-  doRun(RndSpeedTest("sodium"));
+    doRun(RndSpeedTest("sodium"));
 #endif
 #if defined(HAVE_RAND_BYTES)
-  doRun(RndSpeedTest("openssl"));
+    doRun(RndSpeedTest("openssl"));
 #endif
-  doRun(RndSpeedTest("urandom"));
+    doRun(RndSpeedTest("urandom"));
 
-  doRun(NSEC3HashTest(1, "ABCD"));
-  doRun(NSEC3HashTest(10, "ABCD"));
-  doRun(NSEC3HashTest(50, "ABCD"));
-  doRun(NSEC3HashTest(150, "ABCD"));
-  doRun(NSEC3HashTest(500, "ABCD"));
+    doRun(NSEC3HashTest(1, "ABCD"));
+    doRun(NSEC3HashTest(10, "ABCD"));
+    doRun(NSEC3HashTest(50, "ABCD"));
+    doRun(NSEC3HashTest(150, "ABCD"));
+    doRun(NSEC3HashTest(500, "ABCD"));
 
-  doRun(NSEC3HashTest(1, "ABCDABCDABCDABCDABCDABCDABCDABCD"));
-  doRun(NSEC3HashTest(10, "ABCDABCDABCDABCDABCDABCDABCDABCD"));
-  doRun(NSEC3HashTest(50, "ABCDABCDABCDABCDABCDABCDABCDABCD"));
-  doRun(NSEC3HashTest(150, "ABCDABCDABCDABCDABCDABCDABCDABCD"));
-  doRun(NSEC3HashTest(500, "ABCDABCDABCDABCDABCDABCDABCDABCD"));
+    doRun(NSEC3HashTest(1, "ABCDABCDABCDABCDABCDABCDABCDABCD"));
+    doRun(NSEC3HashTest(10, "ABCDABCDABCDABCDABCDABCDABCDABCD"));
+    doRun(NSEC3HashTest(50, "ABCDABCDABCDABCDABCDABCDABCDABCD"));
+    doRun(NSEC3HashTest(150, "ABCDABCDABCDABCDABCDABCDABCDABCD"));
+    doRun(NSEC3HashTest(500, "ABCDABCDABCDABCDABCDABCDABCDABCD"));
 
 #if defined(HAVE_LIBSODIUM) && defined(HAVE_EVP_PKEY_CTX_SET1_SCRYPT_SALT)
-  doRun(CredentialsHashTest());
-  doRun(CredentialsVerifyTest());
+    doRun(CredentialsHashTest());
+    doRun(CredentialsVerifyTest());
 #endif
 
 #ifndef RECURSOR
-  S.doRings();
+    S.doRings();
 
-  S.declareRing("testring", "Just some ring where we'll account things");
-  doRun(StatRingDNSNameQTypeToStringTest(DNSName("example.com"), QType(1)));
+    S.declareRing("testring", "Just some ring where we'll account things");
+    doRun(StatRingDNSNameQTypeToStringTest(DNSName("example.com"), QType(1)));
 
-  S.declareDNSNameQTypeRing("testringdnsname", "Just some ring where we'll account things");
-  doRun(StatRingDNSNameQTypeTest(DNSName("example.com"), QType(1)));
+    S.declareDNSNameQTypeRing("testringdnsname", "Just some ring where we'll account things");
+    doRun(StatRingDNSNameQTypeTest(DNSName("example.com"), QType(1)));
 #endif
 
-  doRun(BurtleHashTest("a string of chars"));
-  doRun(BurtleHashCITest("A String Of Chars"));
+    doRun(BurtleHashTest("a string of chars"));
+    doRun(BurtleHashCITest("A String Of Chars"));
 #ifdef HAVE_LIBSODIUM
-  doRun(SipHashTest("a string of chars"));
+    doRun(SipHashTest("a string of chars"));
 #endif
 
-  cerr<<"Total runs: " << g_totalRuns<<endl;
-}
-catch(std::exception &e)
-{
-  cerr<<"Fatal: "<<e.what()<<endl;
+    cerr<<"Total runs: " << g_totalRuns<<endl;
+  }
+  catch (std::exception &e) {
+    cerr<<"Fatal: "<<e.what()<<endl;
+  }
+  catch (...) {
+    cerr<<"Fatal: unexpected exception"<<endl;
+  }
 }
 
 ArgvMap& arg()
